- y
Response variable, an N x 1 vector.
- x
Control variables, an N x p1 matrix.
- z
Instrumental variables, an N x p2 matrix.
- D
Endogenous treatment variable.
- family
Quantitative for family="gaussian", or family="poisson" (non-negative counts). For family="binomial" should be either a factor with two levels, or a two-column matrix of counts or proportions (the second column is treated as the target class; for a factor, the last level in alphabetical order is the target class). For family="multinomial", can be a nc>=2 level factor, or a matrix with nc columns of counts or proportions. For either "binomial" or "multinomial", if y is presented as a vector, it will be coerced into a factor. For family="cox", y should be a two-column matrix with columns named 'time' and 'status'. The latter is a binary variable, with '1' indicating death, and '0' indicating right censored. The function Surv() in package survival produces such a matrix. For family="mgaussian", y is a matrix of quantitative responses.
- criterion
The criterion by which to select the regularization parameter. One of "BIC", "EBIC", default is "BIC".
- alpha
The elasticnet mixing parameter, with 0<=alpha<= 1. alpha=1 is the lasso penalty, and alpha=0 the ridge penalty.
- nlambda
The number of lambda values, default is 100.
- ...
other arguments, see help(glmnet).