- g
A function of the form \(g(\theta,x)\) and which returns a \(n \times q\) matrix with typical element \(g_i(\theta,x_t)\) for \(i=1,...q\) and \(t=1,...,n\). This matrix is then used to build the q sample moment conditions. It can also be a formula if the model is linear (see details gel).
- x
The design matrix, without an intercept.
- z
The instrument variables matrix.
- max.degree
The upper limit value of degree of B-splines when using BIC/AIC to choose the tuning parameters, default is BIC.
- criterion
The criterion by which to select the regularization parameter. One of "AIC", "BIC","EBIC", "GCV", "AICc"; default is "BIC".
- df.method
How should effective model parameters be calculated? One of: "active", which counts the number of nonzero coefficients; or "default", which uses the calculated df returned by grpreg. default is "default".
- penalty
The penalty to be applied to the model. For group selection, one of grLasso, grMCP, or grSCAD. For bi-level selection, one of gel or cMCP. Default is " grLasso".
- endogenous.index
Specify which variables in design matrix are endogenous variables, the variable corresponds to the value 1 is endogenous variables, the variable corresponds to the value 0 is exogenous variable, the default is all endogenous variables.
- IV.intercept
Intercept of instrument variables, default is “FALSE”.
- family
Either "gaussian" or "binomial", depending on the response, default is "gaussian".
- ...
Arguments passed to gel (such as type,kernel...,detail see gel).